Schematron-derived validation predicates.
Functions
- banner_
requires_ full_ classification - Schematron assertion: Banner must use full classification word.
- is_
valid_ classification - Returns true if the classification level string is a valid CVE value.
- is_
valid_ dissem_ control - Returns true if the dissemination control string is a valid CVE value.
- is_
valid_ sci_ control - Returns true if the SCI control string is a valid CVE value.
- is_
valid_ trigraph - Returns true if the trigraph string is in the CVE country code list.
- noforn_
rel_ exclusive - Schematron assertion: NOFORN and REL TO are mutually exclusive.
- rel_
to_ requires_ trigraph - Schematron assertion: REL TO requires at least one trigraph.