DeclassExemption

Enum DeclassExemption 

#[non_exhaustive]
pub enum DeclassExemption {
Show 25 variants Aea, Nato, NatoAea, X25x1, X25x1Eo12951, X25x2, X25x3, X25x4, X25x5, X25x6, X25x7, X25x8, X25x9, X50x1, X50x1Hum, X50x2, X50x2Wmd, X50x3, X50x4, X50x5, X50x6, X50x7, X50x8, X50x9, X75x,
}
Declassification exemption codes from CVEnumISM25X.xml.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Aea

When using a source document that contains portions of Restricted Data (RD)



Nato

Since NATO information is not to be declassified or downgraded without the prior consent



NatoAea

Handles special case of BOTH NATO and AEA as a single exemption.



X25x1

Reveal the identity of a confidential



X25x1Eo12951

“25X1, EO 12951” (prescribed by the DNI for use on information described in E.O. 12951,



X25x2

Reveal information that would assist



X25x3

Reveal information that would



X25x4

Reveal information that would



X25x5

Reveal formally named or numbered



X25x6

Reveal information, including foreign



X25x7

Reveal information that would



X25x8

Reveal information that would



X25x9

Violate a statute, treaty, or



X50x1

The ISCAP has authorized use of this code in the FBI’s



X50x1Hum

When the information clearly and



X50x2

Reveal information that would assist



X50x2Wmd

When the information clearly and



X50x3

Reveal information that would



X50x4

Reveal information that would



X50x5

Reveal formally named or numbered



X50x6

Reveal information, including foreign



X50x7

Reveal information that would



X50x8

Reveal information that would



X50x9

Violate a statute, treaty, or



X75x

Specific information that has been formally approved by the ISCAP

Implementations

Source

impl DeclassExemption

pub const ALL: &[DeclassExemption]

All valid values in CVE-defined order.

pub fn as_str(&self) -> &'static str

Returns the canonical CVE string representation.

pub fn parse(s: &str) -> Option<Self>

Parse from the canonical CVE string. Returns None for unknown values.