TokenSet

Trait TokenSet 

pub trait TokenSet: Send + Sync {
    // Required methods
    fn canonicalize(&self, token: &str) -> Option<&'static str>;
    fn is_trigraph(&self, token: &str) -> bool;
}
Minimal interface the parser needs from the token set. Implemented by CapcoTokenSet; injected at engine init.

Required Methods

fn canonicalize(&self, token: &str) -> Option<&'static str>

Returns the canonical token string if token is a known CVE value.

fn is_trigraph(&self, token: &str) -> bool

Returns true if token is a known country trigraph.

Implementors